@@ -1,7 +1,7 @@
 """
 Type annotations for emr-containers service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/type_defs/)
 
 Usage::
 
@@ -105,54 +105,95 @@ CancelJobRunResponseTypeDef = TypedDict(
 CertificateTypeDef = TypedDict(
     "CertificateTypeDef",
     {
-        "certificateArn": NotRequired[str],
-        "certificateData": NotRequired[str],
+        "certificateArn": str,
+        "certificateData": str,
     },
+    total=False,
 )
 
-CloudWatchMonitoringConfigurationTypeDef = TypedDict(
-    "CloudWatchMonitoringConfigurationTypeDef",
+_RequiredCloudWatchMonitoringConfigurationTypeDef = TypedDict(
+    "_RequiredCloudWatchMonitoringConfigurationTypeDef",
     {
         "logGroupName": str,
-        "logStreamNamePrefix": NotRequired[str],
     },
 )
+_OptionalCloudWatchMonitoringConfigurationTypeDef = TypedDict(
+    "_OptionalCloudWatchMonitoringConfigurationTypeDef",
+    {
+        "logStreamNamePrefix": str,
+    },
+    total=False,
+)
+
+
+class CloudWatchMonitoringConfigurationTypeDef(
+    _RequiredCloudWatchMonitoringConfigurationTypeDef,
+    _OptionalCloudWatchMonitoringConfigurationTypeDef,
+):
+    pass
+
 
 ConfigurationOverridesTypeDef = TypedDict(
     "ConfigurationOverridesTypeDef",
     {
-        "applicationConfiguration": NotRequired[Sequence["ConfigurationTypeDef"]],
-        "monitoringConfiguration": NotRequired["MonitoringConfigurationTypeDef"],
+        "applicationConfiguration": Sequence["ConfigurationTypeDef"],
+        "monitoringConfiguration": "MonitoringConfigurationTypeDef",
     },
+    total=False,
 )
 
-ConfigurationTypeDef = TypedDict(
-    "ConfigurationTypeDef",
+_RequiredConfigurationTypeDef = TypedDict(
+    "_RequiredConfigurationTypeDef",
     {
         "classification": str,
-        "properties": NotRequired[Mapping[str, str]],
-        "configurations": NotRequired[Sequence[Dict[str, Any]]],
     },
 )
+_OptionalConfigurationTypeDef = TypedDict(
+    "_OptionalConfigurationTypeDef",
+    {
+        "properties": Mapping[str, str],
+        "configurations": Sequence[Dict[str, Any]],
+    },
+    total=False,
+)
+
+
+class ConfigurationTypeDef(_RequiredConfigurationTypeDef, _OptionalConfigurationTypeDef):
+    pass
+
 
 ContainerInfoTypeDef = TypedDict(
     "ContainerInfoTypeDef",
     {
-        "eksInfo": NotRequired["EksInfoTypeDef"],
+        "eksInfo": "EksInfoTypeDef",
     },
+    total=False,
 )
 
-ContainerProviderTypeDef = TypedDict(
-    "ContainerProviderTypeDef",
+_RequiredContainerProviderTypeDef = TypedDict(
+    "_RequiredContainerProviderTypeDef",
     {
         "type": Literal["EKS"],
         "id": str,
-        "info": NotRequired["ContainerInfoTypeDef"],
     },
 )
+_OptionalContainerProviderTypeDef = TypedDict(
+    "_OptionalContainerProviderTypeDef",
+    {
+        "info": "ContainerInfoTypeDef",
+    },
+    total=False,
+)
 
-CreateManagedEndpointRequestRequestTypeDef = TypedDict(
-    "CreateManagedEndpointRequestRequestTypeDef",
+
+class ContainerProviderTypeDef(
+    _RequiredContainerProviderTypeDef, _OptionalContainerProviderTypeDef
+):
+    pass
+
+
+_RequiredCreateManagedEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateManagedEndpointRequestRequestTypeDef",
     {
         "name": str,
         "virtualClusterId": str,
@@ -160,11 +201,25 @@ CreateManagedEndpointRequestRequestTypeDef = TypedDict(
         "releaseLabel": str,
         "executionRoleArn": str,
         "clientToken": str,
-        "certificateArn": NotRequired[str],
-        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
-        "tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateManagedEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateManagedEndpointRequestRequestTypeDef",
+    {
+        "certificateArn": str,
+        "configurationOverrides": "ConfigurationOverridesTypeDef",
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateManagedEndpointRequestRequestTypeDef(
+    _RequiredCreateManagedEndpointRequestRequestTypeDef,
+    _OptionalCreateManagedEndpointRequestRequestTypeDef,
+):
+    pass
+
 
 CreateManagedEndpointResponseTypeDef = TypedDict(
     "CreateManagedEndpointResponseTypeDef",
@@ -177,15 +232,29 @@ CreateManagedEndpointResponseTypeDef = TypedDict(
     },
 )
 
-CreateVirtualClusterRequestRequestTypeDef = TypedDict(
-    "CreateVirtualClusterRequestRequestTypeDef",
+_RequiredCreateVirtualClusterRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateVirtualClusterRequestRequestTypeDef",
     {
         "name": str,
         "containerProvider": "ContainerProviderTypeDef",
         "clientToken": str,
-        "tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateVirtualClusterRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateVirtualClusterRequestRequestTypeDef",
+    {
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateVirtualClusterRequestRequestTypeDef(
+    _RequiredCreateVirtualClusterRequestRequestTypeDef,
+    _OptionalCreateVirtualClusterRequestRequestTypeDef,
+):
+    pass
+
 
 CreateVirtualClusterResponseTypeDef = TypedDict(
     "CreateVirtualClusterResponseTypeDef",
@@ -279,87 +348,118 @@ DescribeVirtualClusterResponseTypeDef = TypedDict(
 EksInfoTypeDef = TypedDict(
     "EksInfoTypeDef",
     {
-        "namespace": NotRequired[str],
+        "namespace": str,
     },
+    total=False,
 )
 
 EndpointTypeDef = TypedDict(
     "EndpointTypeDef",
     {
-        "id": NotRequired[str],
-        "name": NotRequired[str],
-        "arn": NotRequired[str],
-        "virtualClusterId": NotRequired[str],
-        "type": NotRequired[str],
-        "state": NotRequired[EndpointStateType],
-        "releaseLabel": NotRequired[str],
-        "executionRoleArn": NotRequired[str],
-        "certificateArn": NotRequired[str],
-        "certificateAuthority": NotRequired["CertificateTypeDef"],
-        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
-        "serverUrl": NotRequired[str],
-        "createdAt": NotRequired[datetime],
-        "securityGroup": NotRequired[str],
-        "subnetIds": NotRequired[List[str]],
-        "stateDetails": NotRequired[str],
-        "failureReason": NotRequired[FailureReasonType],
-        "tags": NotRequired[Dict[str, str]],
+        "id": str,
+        "name": str,
+        "arn": str,
+        "virtualClusterId": str,
+        "type": str,
+        "state": EndpointStateType,
+        "releaseLabel": str,
+        "executionRoleArn": str,
+        "certificateArn": str,
+        "certificateAuthority": "CertificateTypeDef",
+        "configurationOverrides": "ConfigurationOverridesTypeDef",
+        "serverUrl": str,
+        "createdAt": datetime,
+        "securityGroup": str,
+        "subnetIds": List[str],
+        "stateDetails": str,
+        "failureReason": FailureReasonType,
+        "tags": Dict[str, str],
     },
+    total=False,
 )
 
 JobDriverTypeDef = TypedDict(
     "JobDriverTypeDef",
     {
-        "sparkSubmitJobDriver": NotRequired["SparkSubmitJobDriverTypeDef"],
+        "sparkSubmitJobDriver": "SparkSubmitJobDriverTypeDef",
     },
+    total=False,
 )
 
 JobRunTypeDef = TypedDict(
     "JobRunTypeDef",
     {
-        "id": NotRequired[str],
-        "name": NotRequired[str],
-        "virtualClusterId": NotRequired[str],
-        "arn": NotRequired[str],
-        "state": NotRequired[JobRunStateType],
-        "clientToken": NotRequired[str],
-        "executionRoleArn": NotRequired[str],
-        "releaseLabel": NotRequired[str],
-        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
-        "jobDriver": NotRequired["JobDriverTypeDef"],
-        "createdAt": NotRequired[datetime],
-        "createdBy": NotRequired[str],
-        "finishedAt": NotRequired[datetime],
-        "stateDetails": NotRequired[str],
-        "failureReason": NotRequired[FailureReasonType],
-        "tags": NotRequired[Dict[str, str]],
+        "id": str,
+        "name": str,
+        "virtualClusterId": str,
+        "arn": str,
+        "state": JobRunStateType,
+        "clientToken": str,
+        "executionRoleArn": str,
+        "releaseLabel": str,
+        "configurationOverrides": "ConfigurationOverridesTypeDef",
+        "jobDriver": "JobDriverTypeDef",
+        "createdAt": datetime,
+        "createdBy": str,
+        "finishedAt": datetime,
+        "stateDetails": str,
+        "failureReason": FailureReasonType,
+        "tags": Dict[str, str],
     },
+    total=False,
 )
 
-ListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
-    "ListJobRunsRequestListJobRunsPaginateTypeDef",
+_RequiredListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
+    "_RequiredListJobRunsRequestListJobRunsPaginateTypeDef",
     {
         "virtualClusterId": str,
-        "createdBefore": NotRequired[Union[datetime, str]],
-        "createdAfter": NotRequired[Union[datetime, str]],
-        "name": NotRequired[str],
-        "states": NotRequired[Sequence[JobRunStateType]],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListJobRunsRequestListJobRunsPaginateTypeDef = TypedDict(
+    "_OptionalListJobRunsRequestListJobRunsPaginateTypeDef",
+    {
+        "createdBefore": Union[datetime, str],
+        "createdAfter": Union[datetime, str],
+        "name": str,
+        "states": Sequence[JobRunStateType],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListJobRunsRequestRequestTypeDef = TypedDict(
-    "ListJobRunsRequestRequestTypeDef",
+
+class ListJobRunsRequestListJobRunsPaginateTypeDef(
+    _RequiredListJobRunsRequestListJobRunsPaginateTypeDef,
+    _OptionalListJobRunsRequestListJobRunsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListJobRunsRequestRequestTypeDef = TypedDict(
+    "_RequiredListJobRunsRequestRequestTypeDef",
     {
         "virtualClusterId": str,
-        "createdBefore": NotRequired[Union[datetime, str]],
-        "createdAfter": NotRequired[Union[datetime, str]],
-        "name": NotRequired[str],
-        "states": NotRequired[Sequence[JobRunStateType]],
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListJobRunsRequestRequestTypeDef = TypedDict(
+    "_OptionalListJobRunsRequestRequestTypeDef",
+    {
+        "createdBefore": Union[datetime, str],
+        "createdAfter": Union[datetime, str],
+        "name": str,
+        "states": Sequence[JobRunStateType],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListJobRunsRequestRequestTypeDef(
+    _RequiredListJobRunsRequestRequestTypeDef, _OptionalListJobRunsRequestRequestTypeDef
+):
+    pass
+
 
 ListJobRunsResponseTypeDef = TypedDict(
     "ListJobRunsResponseTypeDef",
@@ -370,30 +470,58 @@ ListJobRunsResponseTypeDef = TypedDict(
     },
 )
 
-ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
-    "ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
+_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
+    "_RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
     {
         "virtualClusterId": str,
-        "createdBefore": NotRequired[Union[datetime, str]],
-        "createdAfter": NotRequired[Union[datetime, str]],
-        "types": NotRequired[Sequence[str]],
-        "states": NotRequired[Sequence[EndpointStateType]],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef = TypedDict(
+    "_OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef",
+    {
+        "createdBefore": Union[datetime, str],
+        "createdAfter": Union[datetime, str],
+        "types": Sequence[str],
+        "states": Sequence[EndpointStateType],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListManagedEndpointsRequestRequestTypeDef = TypedDict(
-    "ListManagedEndpointsRequestRequestTypeDef",
+
+class ListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef(
+    _RequiredListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
+    _OptionalListManagedEndpointsRequestListManagedEndpointsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListManagedEndpointsRequestRequestTypeDef = TypedDict(
+    "_RequiredListManagedEndpointsRequestRequestTypeDef",
     {
         "virtualClusterId": str,
-        "createdBefore": NotRequired[Union[datetime, str]],
-        "createdAfter": NotRequired[Union[datetime, str]],
-        "types": NotRequired[Sequence[str]],
-        "states": NotRequired[Sequence[EndpointStateType]],
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
     },
 )
+_OptionalListManagedEndpointsRequestRequestTypeDef = TypedDict(
+    "_OptionalListManagedEndpointsRequestRequestTypeDef",
+    {
+        "createdBefore": Union[datetime, str],
+        "createdAfter": Union[datetime, str],
+        "types": Sequence[str],
+        "states": Sequence[EndpointStateType],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListManagedEndpointsRequestRequestTypeDef(
+    _RequiredListManagedEndpointsRequestRequestTypeDef,
+    _OptionalListManagedEndpointsRequestRequestTypeDef,
+):
+    pass
+
 
 ListManagedEndpointsResponseTypeDef = TypedDict(
     "ListManagedEndpointsResponseTypeDef",
@@ -422,26 +550,28 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 ListVirtualClustersRequestListVirtualClustersPaginateTypeDef = TypedDict(
     "ListVirtualClustersRequestListVirtualClustersPaginateTypeDef",
     {
-        "containerProviderId": NotRequired[str],
-        "containerProviderType": NotRequired[Literal["EKS"]],
-        "createdAfter": NotRequired[Union[datetime, str]],
-        "createdBefore": NotRequired[Union[datetime, str]],
-        "states": NotRequired[Sequence[VirtualClusterStateType]],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "containerProviderId": str,
+        "containerProviderType": Literal["EKS"],
+        "createdAfter": Union[datetime, str],
+        "createdBefore": Union[datetime, str],
+        "states": Sequence[VirtualClusterStateType],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListVirtualClustersRequestRequestTypeDef = TypedDict(
     "ListVirtualClustersRequestRequestTypeDef",
     {
-        "containerProviderId": NotRequired[str],
-        "containerProviderType": NotRequired[Literal["EKS"]],
-        "createdAfter": NotRequired[Union[datetime, str]],
-        "createdBefore": NotRequired[Union[datetime, str]],
-        "states": NotRequired[Sequence[VirtualClusterStateType]],
-        "maxResults": NotRequired[int],
-        "nextToken": NotRequired[str],
+        "containerProviderId": str,
+        "containerProviderType": Literal["EKS"],
+        "createdAfter": Union[datetime, str],
+        "createdBefore": Union[datetime, str],
+        "states": Sequence[VirtualClusterStateType],
+        "maxResults": int,
+        "nextToken": str,
     },
+    total=False,
 )
 
 ListVirtualClustersResponseTypeDef = TypedDict(
@@ -456,21 +586,21 @@ ListVirtualClustersResponseTypeDef = TypedDict(
 MonitoringConfigurationTypeDef = TypedDict(
     "MonitoringConfigurationTypeDef",
     {
-        "persistentAppUI": NotRequired[PersistentAppUIType],
-        "cloudWatchMonitoringConfiguration": NotRequired[
-            "CloudWatchMonitoringConfigurationTypeDef"
-        ],
-        "s3MonitoringConfiguration": NotRequired["S3MonitoringConfigurationTypeDef"],
+        "persistentAppUI": PersistentAppUIType,
+        "cloudWatchMonitoringConfiguration": "CloudWatchMonitoringConfigurationTypeDef",
+        "s3MonitoringConfiguration": "S3MonitoringConfigurationTypeDef",
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -491,28 +621,54 @@ S3MonitoringConfigurationTypeDef = TypedDict(
     },
 )
 
-SparkSubmitJobDriverTypeDef = TypedDict(
-    "SparkSubmitJobDriverTypeDef",
+_RequiredSparkSubmitJobDriverTypeDef = TypedDict(
+    "_RequiredSparkSubmitJobDriverTypeDef",
     {
         "entryPoint": str,
-        "entryPointArguments": NotRequired[List[str]],
-        "sparkSubmitParameters": NotRequired[str],
     },
 )
+_OptionalSparkSubmitJobDriverTypeDef = TypedDict(
+    "_OptionalSparkSubmitJobDriverTypeDef",
+    {
+        "entryPointArguments": List[str],
+        "sparkSubmitParameters": str,
+    },
+    total=False,
+)
 
-StartJobRunRequestRequestTypeDef = TypedDict(
-    "StartJobRunRequestRequestTypeDef",
+
+class SparkSubmitJobDriverTypeDef(
+    _RequiredSparkSubmitJobDriverTypeDef, _OptionalSparkSubmitJobDriverTypeDef
+):
+    pass
+
+
+_RequiredStartJobRunRequestRequestTypeDef = TypedDict(
+    "_RequiredStartJobRunRequestRequestTypeDef",
     {
         "virtualClusterId": str,
         "clientToken": str,
         "executionRoleArn": str,
         "releaseLabel": str,
         "jobDriver": "JobDriverTypeDef",
-        "name": NotRequired[str],
-        "configurationOverrides": NotRequired["ConfigurationOverridesTypeDef"],
-        "tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalStartJobRunRequestRequestTypeDef = TypedDict(
+    "_OptionalStartJobRunRequestRequestTypeDef",
+    {
+        "name": str,
+        "configurationOverrides": "ConfigurationOverridesTypeDef",
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class StartJobRunRequestRequestTypeDef(
+    _RequiredStartJobRunRequestRequestTypeDef, _OptionalStartJobRunRequestRequestTypeDef
+):
+    pass
+
 
 StartJobRunResponseTypeDef = TypedDict(
     "StartJobRunResponseTypeDef",
@@ -544,12 +700,13 @@ UntagResourceRequestRequestTypeDef = TypedDict(
 VirtualClusterTypeDef = TypedDict(
     "VirtualClusterTypeDef",
     {
-        "id": NotRequired[str],
-        "name": NotRequired[str],
-        "arn": NotRequired[str],
-        "state": NotRequired[VirtualClusterStateType],
-        "containerProvider": NotRequired["ContainerProviderTypeDef"],
-        "createdAt": NotRequired[datetime],
-        "tags": NotRequired[Dict[str, str]],
+        "id": str,
+        "name": str,
+        "arn": str,
+        "state": VirtualClusterStateType,
+        "containerProvider": "ContainerProviderTypeDef",
+        "createdAt": datetime,
+        "tags": Dict[str, str],
     },
+    total=False,
 )
